#[auth_controller]Expand description
Marks an auth controller impl, preserving generic type parameters (unlike
doido_controller::controller on impl<U> …).
#[auth_controller]Marks an auth controller impl, preserving generic type parameters (unlike
doido_controller::controller on impl<U> …).