init_test_auth

Function init_test_auth 

pub async fn init_test_auth(
    db: DatabaseConnection,
    config: AuthConfig,
) -> Result<AuthTestGuard, AuthError>
Initialise in-memory auth state for tests.

Returns a guard that must be held for the whole test so parallel tests do not clobber process-global auth state.