pub async fn init_test_auth(
db: DatabaseConnection,
config: AuthConfig,
) -> Result<AuthTestGuard, AuthError>Expand description
Initialise in-memory auth state for tests.
Returns a guard that must be held for the whole test so parallel tests do not clobber process-global auth state.